==> calligra_2.3.85.orig.tar.bz2: calligra-2.3.85/plugins/textshape/dialogs/ParagraphSettingsDialog.cpp <==
/* This file is part of the KDE project
 * Copyright (C) 2007, 2010 Thomas Zander <zander@kde.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public License
 * along with this library; see the file COPYING.LIB.  If not, write to
 * the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
 * Boston, MA 02110-1301, USA.
 */

#include "ParagraphSettingsDialog.h"

#include "ParagraphGeneral.h"
#include "../TextTool.h"

#include <KoParagraphStyle.h>
#include <KoTextDocument.h>
#include <KoTextEditor.h>

#include <QTextBlock>
#include <QTimer>

ParagraphSettingsDialog::ParagraphSettingsDialog(TextTool *tool, QTextCursor *cursor, QWidget* parent)
        : KDialog(parent),
        m_tool(tool),
        m_cursor(cursor)
{
    setCaption(i18n("Paragraph Format"));
    setModal(true);
    setButtons(Ok | Cancel | Apply);
    setDefaultButton(Ok);

    m_paragraphGeneral = new ParagraphGeneral;
    m_paragraphGeneral->hideStyleName(true);
    setMainWidget(m_paragraphGeneral);

    connect(this, SIGNAL(applyClicked()), this, SLOT(slotApply()));
    connect(this, SIGNAL(okClicked()), this, SLOT(slotOk()));
    initTabs();
}

ParagraphSettingsDialog::~ParagraphSettingsDialog()
{
}

void ParagraphSettingsDialog::initTabs()
{
    KoParagraphStyle *style = KoParagraphStyle::fromBlock(m_cursor->block());
    m_paragraphGeneral->setStyle(style, KoList::level(m_cursor->block()));
}

void ParagraphSettingsDialog::slotOk()
{
    slotApply();
    KDialog::accept();
}

void ParagraphSettingsDialog::slotApply()
{
    emit startMacro(i18n("Paragraph Settings"));
    KoParagraphStyle chosenStyle;
    m_paragraphGeneral->save(&chosenStyle);
    QTextBlockFormat format;
    chosenStyle.applyStyle(format);
    m_cursor->mergeBlockFormat(format);
    if (chosenStyle.listStyle()) {
        KoTextEditor::ChangeListFlags flags(KoTextEditor::AutoListStyle | KoTextEditor::DontUnsetIfSame);
        m_tool->textEditor()->setListProperties(static_cast<KoListStyle::Style>(chosenStyle.listStyle()->styleId()),
                                                chosenStyle.listStyle()->listLevels().first(),
                                                flags);

    } else {
        QTextList *list = m_cursor->block().textList();
        if (list) { // then remove it.
            list->remove(m_cursor->block());
        }
    }
    emit stopMacro();
}

void ParagraphSettingsDialog::setUnit(const KoUnit &unit)
{
    m_paragraphGeneral->setUnit(unit);
}

#include <ParagraphSettingsDialog.moc>

==> calligra_2.5.3.orig.tar.bz2: calligra-2.5.3/plugins/textshape/dialogs/ParagraphSettingsDialog.cpp <==
/* This file is part of the KDE project
 * Copyright (C) 2007, 2010 Thomas Zander <zander@kde.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public License
 * along with this library; see the file COPYING.LIB.  If not, write to
 * the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
 * Boston, MA 02110-1301, USA.
 */

#include "ParagraphSettingsDialog.h"

#include "ParagraphGeneral.h"
#include "../TextTool.h"

#include <KoParagraphStyle.h>
#include <KoTextDocument.h>
#include <KoTextEditor.h>
#include <KoListLevelProperties.h>

#include <QTextBlock>
#include <QTimer>

ParagraphSettingsDialog::ParagraphSettingsDialog(TextTool *tool, KoTextEditor *editor, QWidget* parent)
        : KDialog(parent)
        , m_tool(tool)
        , m_editor(editor)
        , m_styleChanged(false)
{
    setCaption(i18n("Paragraph Format"));
    setModal(true);
    setButtons(Ok | Cancel | Apply);
    setDefaultButton(Ok);

    m_paragraphGeneral = new ParagraphGeneral;
    m_paragraphGeneral->hideStyleName(true);
    setMainWidget(m_paragraphGeneral);


    connect(this, SIGNAL(applyClicked()), this, SLOT(slotApply()));
    connect(this, SIGNAL(okClicked()), this, SLOT(slotOk()));
    initTabs();

    // Do this after initTabs so it doesn't cause signals prematurely
    connect(m_paragraphGeneral, SIGNAL(styleChanged()), this, SLOT(styleChanged()));
}

ParagraphSettingsDialog::~ParagraphSettingsDialog()
{
}

void ParagraphSettingsDialog::initTabs()
{
    KoParagraphStyle *style = KoParagraphStyle::fromBlock(m_editor->block());
    m_paragraphGeneral->setStyle(style, KoList::level(m_editor->block()));
}

void ParagraphSettingsDialog::styleChanged(bool state)
{
    m_styleChanged = state;
}

void ParagraphSettingsDialog::slotOk()
{
    slotApply();
    KDialog::accept();
}

void ParagraphSettingsDialog::slotApply()
{
    if (!m_styleChanged)
        return;

    m_editor->beginEditBlock(i18n("Paragraph Settings"));
    KoParagraphStyle chosenStyle;
    m_paragraphGeneral->save(&chosenStyle);
    QTextCharFormat cformat;
    QTextBlockFormat format;
    chosenStyle.KoCharacterStyle::applyStyle(cformat);
    chosenStyle.applyStyle(format);

    m_editor->mergeAutoStyle(cformat, format);
    if (chosenStyle.listStyle()) {
        KoTextEditor::ChangeListFlags flags(KoTextEditor::AutoListStyle | KoTextEditor::DontUnsetIfSame);
        m_tool->textEditor()->setListProperties(chosenStyle.listStyle()->levelProperties(chosenStyle.listStyle()->listLevels().first()),
                                                flags);
    } else {
        QTextList *list = m_editor->block().textList();
        if (list) { // then remove it.
            list->remove(m_editor->block());
        }
    }
    m_editor->endEditBlock();
    m_styleChanged = false;
}

void ParagraphSettingsDialog::setUnit(const KoUnit &unit)
{
    m_paragraphGeneral->setUnit(unit);
}

void ParagraphSettingsDialog::setImageCollection(KoImageCollection *imageCollection)
{
    m_paragraphGeneral->setImageCollection(imageCollection);
}

#include <ParagraphSettingsDialog.moc>
